# CUDA_jll.jl

This is an autogenerated package constructed using [`BinaryBuilder.jl`](https://github.com/JuliaPackaging/BinaryBuilder.jl).

## Products

The code bindings within this package are autogenerated from the following `Products` defined within the `build_tarballs.jl` file that generated this package:

```julia
products = [
    LibraryProduct(["libcufftw", "cufftw64_100"], :libcufftw),
    LibraryProduct(["libcusolver", "cusolver64_100"], :libcusolver),
    LibraryProduct(["libcusparse", "cusparse64_100"], :libcusparse),
    LibraryProduct(["libcudart", "cudart64_100"], :libcudart),
    ExecutableProduct(["nvdisasm"], :nvdisasm),
    LibraryProduct(["libnppist", "nppist64_100"], :libnppist),
    LibraryProduct(["libnppitc", "nppitc64_100"], :libnppitc),
    LibraryProduct(["libnppicom", "nppicom64_100"], :libnppicom),
    LibraryProduct(["libnppif", "nppif64_100"], :libnppif),
    LibraryProduct(["libnppicc", "nppicc64_100"], :libnppicc),
    LibraryProduct(["libcurand", "curand64_100"], :libcurand),
    LibraryProduct(["libnppim", "nppim64_100"], :libnppim),
    LibraryProduct(["libnppidei", "nppidei64_100"], :libnppidei),
    LibraryProduct(["libcupti", "cupti64_100"], :libcupti),
    LibraryProduct(["libcublas", "cublas64_100"], :libcublas),
    LibraryProduct(["libcufft", "cufft64_100"], :libcufft),
    LibraryProduct(["libnppial", "nppial64_100"], :libnppial),
    FileProduct(["lib/libcudadevrt.a", "lib/cudadevrt.lib"], :libcudadevrt),
    LibraryProduct(["libnvvm", "nvvm64_33_0"], :libnvvm),
    LibraryProduct(["libnppig", "nppig64_100"], :libnppig),
    LibraryProduct(["libnvgraph", "nvgraph64_100"], :libcurand),
    LibraryProduct(["libnpps", "npps64_100"], :libnpps),
    LibraryProduct(["libnvblas", "nvblas64_100"], :libnvblas),
    FileProduct(["share/libdevice/libdevice.10.bc"], :libdevice),
    LibraryProduct(["libnppisu", "nppisu64_100"], :libnppisu),
    LibraryProduct(["libnppc", "nppc64_100"], :libnppc),
    LibraryProduct(["libnvToolsExt", "nvToolsExt64_1"], :libnvtoolsext)
]
```

## Usage example

For example purposes, we will assume that the following products were defined in the imaginary package `Example_jll`:

```julia
products = [
    FileProduct("src/data.txt", :data_txt),
    LibraryProduct("libdataproc", :libdataproc),
    ExecutableProduct("mungify", :mungify_exe)
]
```

With such products defined, `Example_jll` would contain `data_txt`, `libdataproc` and `mungify_exe` symbols exported. For `FileProduct` variables, the exported value is a string pointing to the location of the file on-disk.  For `LibraryProduct` variables, it is a string corresponding to the `SONAME` of the desired library (it will have already been `dlopen()`'ed, so typical `ccall()` usage applies), and for `ExecutableProduct` variables, the exported value is a function that can be called to set appropriate environment variables.  Example:

```julia
using Example_jll

# For file products, you can access its file location directly:
data_lines = open(data_txt, "r") do io
    readlines(io)
end

# For library products, you can use the exported variable name in `ccall()` invocations directly
num_chars = ccall((:count_characters, libdataproc), Cint, (Cstring, Cint), data_lines[1], length(data_lines[1]))

# For executable products, you can use the exported variable name as a function that you can call
mungify_exe() do mungify_exe_path
    run(`$mungify_exe_path $num_chars`)
end
```
